Video class
===========

This page documents the :class:`pyneon.Video` class, which provides an interface for working with video data in PyNeon.
It also documents the :func:`pyneon.find_homographies` function, which computes homography transformations for video frames
based on marker and contour layouts.

.. autoclass:: pyneon.Video
    :members:
    :show-inheritance:

.. autofunction:: pyneon.find_homographies

